const transform = require('..');

function getClassComponent(template) {
  return `
    import { Component } from 'rax';
    export default class extends Component {
      render() {
        return (${template});
      }
    }
  `;
}

describe('transform', () => {
  it ('should work in basic', () => {
    const rawTemplate = `
      <div ref="wrap" class="wrapper">
        <text style="color: #ccc">Hello Weex Eagle!</text>
      </div>
    `;

    const expected = {
      body: {
        tagName: 'div',
        nodeId: '1',
        ref: 'wrap',
        classList: ['wrapper'],
        childNodes: [
          {
            tagName: 'text',
            nodeId: '2',
            style: [
              {
                color: 'rgb(204,204,204)'
              }
            ],
            attributes: {
              value: ['Hello Weex Eagle!'],
            }
          }
        ]
      },
      components: [],
      data: {},
      props: {},
      styles: {},
    };

    const transformed = transform(getClassComponent(rawTemplate), {
      filePath: process.cwd() + '/index.jsx',
      rootContext: process.cwd(),
    });
    expect(transformed).toEqual(expected);
  });
});
