const transform = require('../index');
const cwd = process.cwd();

function getFunctionalComponent(template, fnExp = '') {
  return `
    import { Component } from 'rax';
    import A from 'rax-view';
    
    export default function foo() {
      ${fnExp}
      return (${template});
    }
  `;
}

describe('transform functional component', () => {
  it('basic and props', () => {
    const code = getFunctionalComponent(`
      <view foo={bar} hello="world">
        <text>hello world</text>
      </view>
    `);

    const received = transform(code, {
      filePath: cwd + '/index.jsx',
      rootContext: cwd,
    });

    const expected = {
      nodeId: '1',
      tagName: 'view',
      attributes: {
        foo: { '@binding': 'bar' },
        hello: 'world',
      },
      childNodes: [
        {
          tagName: 'text',
          nodeId: '2',
          attributes: {
            value: ['hello world'],
          },
        }
      ],
    };

    expect(received.body).toEqual(expected);
  });

  it('customComponents', () => {
    const code = getFunctionalComponent(`
      <A foo={bar} hello="world">
        <text>hello world</text>
      </A>
    `);

    const received = transform(code, {
      filePath: cwd + '/index.jsx',
      rootContext: cwd,
    });

    const expected = {
      nodeId: '1',
      tagName: 'A',
      attributes: {
        foo: { '@binding': 'bar' },
        hello: 'world',
      },
      isComponent: true,
      componentAlias: {},
      childNodes: [
        {
          tagName: 'text',
          nodeId: '2',
          attributes: {
            value: ['hello world'],
          },
        }
      ],
    };

    expect(received.body).toEqual(expected);
  });

  it('useState', () => {
    const code = getFunctionalComponent(`
      <A foo={bar} hello="world" onClick={() => setBar(bar + 1)}>
        <text>hello world</text>
      </A>
    `, `
      const [ bar, setBar ] = useState(1);
    `);

    const received = transform(code, {
      filePath: cwd + '/index.jsx',
      rootContext: cwd,
    });

    const expected = {
      nodeId: '1',
      tagName: 'A',
      attributes: {
        foo: { '@binding': 'bar' },
        hello: 'world',
      },
      isComponent: true,
      componentAlias: {},
      childNodes: [
        {
          tagName: 'text',
          nodeId: '2',
          attributes: {
            value: ['hello world'],
          },
        }
      ],
    };

    expect(received.body).toEqual(expected);
  });
});
