const css = require('css');
const transformer = require('stylesheet-loader/lib/transformer');

const RULE = 'rule';
const FONT_FACE_RULE = 'font-face';
const MEDIA_RULE = 'media';

/**
 * Transform css text to css object.
 * @NOTE: Not support font-face or media-query, which will case error thrown.
 * @param source CSS text.
 * @param options?
 */
module.exports = function transformStyle(source, options = {}) {
  const stylesheet = css.parse(source).stylesheet;
  return parse(stylesheet, options);
}

/**
 * Parse css compiled result to styles object.
 * @param stylesheet
 * @param options
 */
function parse(stylesheet, options = {}) {
  let styles = {};
  const { transformDescendantCombinator } = options;

  stylesheet.rules.forEach(function(rule) {
    let style = {};

    // normal rule
    if (rule.type === RULE) {
      style = transformer.convert(rule);

      rule.selectors.forEach((selector) => {
        let sanitizedSelector = transformer.sanitizeSelector(selector, transformDescendantCombinator, rule.position);

        if (sanitizedSelector) {
          // handle pseudo class
          const pseudoIndex = sanitizedSelector.indexOf(':');
          if (pseudoIndex > -1) {
            let pseudoStyle = {};
            const pseudoName = selector.slice(pseudoIndex + 1);
            sanitizedSelector = sanitizedSelector.slice(0, pseudoIndex);

            Object.keys(style).forEach((prop) => {
              pseudoStyle[prop + pseudoName] = style[prop];
            });

            style = pseudoStyle;
          }

          styles[sanitizedSelector] = Object.assign(styles[sanitizedSelector] || {}, style);
        }
      });
    }

    // font face rule
    if (rule.type === FONT_FACE_RULE) {
      throw new Error('Not support font face rule in CSS.')
    }

    // media rule
    if (rule.type === MEDIA_RULE) {
      throw new Error('Not support media query in CSS.')
    }
  });

  return styles;
}
